@@ -13,11 +13,11 @@ interp <- function(x, y=NULL, z,
                    duplicate = "error", dupfun = NULL,
                    nx = 40, ny = 40, input = "points", output = "grid",
                    method="linear", deltri="shull",
-                   h=0, kernel="uniform", solver="QR", degree=3,
+                   h=0, kernel="gaussian", solver="QR", degree=3,
                    baryweight=TRUE,
                    autodegree=FALSE,
                    adtol=0.1,
-                   smoothpde=TRUE,
+                   smoothpde=FALSE,
                    akimaweight=TRUE,
                    nweight=25)
     {
@@ -107,6 +107,15 @@ interp <- function(x, y=NULL, z,
                                    baryweight,
                                    autodegree,adtol,
                                    smoothpde,akimaweight,nweight)
+                if(ans$err==-13){
+                  ## retry with jitter
+                  ans <- interpShull(xo,yo,jitter(x,1e-3),jitter(y,1e-3),z,linear,input,output,
+                                     kernel,h,
+                                     solver,degree,
+                                     baryweight,
+                                     autodegree,adtol,
+                                     smoothpde,akimaweight,nweight)
+                }
                 if(output=="points") # back to vector from matrix:
                     ans$z <- c(ans$z)
             } else
